@@ -1,9 +1,11 @@
 hlnorm <- function(x, meanlog = 0, sdlog = 1,
-                   shape = 1 / sdlog, scale = exp(meanlog), log = FALSE){
+                   shape = 1 / sdlog, scale = exp(meanlog), prop = 1,
+                   log = FALSE){
+    ## 'prop' added in version 2.3-0. 
     ## shape = 1 / sdlog, scale = exp(meanlog)
     meanlog <- log(scale)
     sdlog <- 1 / shape
-    ret <- dlnorm(x, meanlog, sdlog) /
+    ret <- prop * dlnorm(x, meanlog, sdlog) /
         plnorm(x, meanlog, sdlog, lower.tail = FALSE)
     if (log) ret <- ifelse(ret <= 0, -Inf, log(ret))
     return (ret)
@@ -11,10 +13,13 @@ hlnorm <- function(x, meanlog = 0, sdlog = 1,
 }
 
 Hlnorm <- function(x, meanlog = 0, sdlog = 1,
-                   shape = 1 / sdlog, scale = exp(meanlog), log.p = FALSE){
+                   shape = 1 / sdlog, scale = exp(meanlog), prop = 1,
+                   log.p = FALSE){
+    ## 'prop' added in version 2.3-0. 
+    ## shape = 1 / sdlog, scale = exp(meanlog)
     meanlog <- log(scale)
     sdlog <- 1 / shape
-    ret <- -plnorm(x, meanlog, sdlog, lower.tail = FALSE, log.p = TRUE)
+    ret <- -prop * plnorm(x, meanlog, sdlog, lower.tail = FALSE, log.p = TRUE)
     if (log.p) ret <- log(ret)
     return (ret)
 }
